package com.bonus.sgzb.material.service;


import com.bonus.sgzb.base.api.domain.BackApplyInfo;
import com.bonus.sgzb.material.domain.TmTask;

import java.util.List;

/**
 * 任务tm_taskService接口
 * 
 * @author bonus
 * @date 2023-12-13
 */
public interface TaskService
{
    /**
     * 查询任务tm_task
     * 
     * @param taskId 任务tm_task主键
     * @return 任务tm_task
     */
    public TmTask selectTmTaskByTaskId(Long taskId);

    /**
     * 查询任务tm_task列表
     * 
     * @param tmTask 任务tm_task
     * @return 任务tm_task集合
     */
    public List<TmTask> selectTmTaskList(TmTask tmTask);

    /**
     * 新增任务tm_task
     * 
     * @param tmTask 任务tm_task
     * @return 结果
     */
    public int insertTmTask(TmTask tmTask);

    /**
     * 修改任务tm_task
     * 
     * @param tmTask 任务tm_task
     * @return 结果
     */
    public int updateTmTask(TmTask tmTask);

    /**
     * 批量删除任务tm_task
     * 
     * @param taskIds 需要删除的任务tm_task主键集合
     * @return 结果
     */
    public int deleteTmTaskByTaskIds(Long[] taskIds);

    /**
     * 删除任务tm_task信息
     * 
     * @param taskId 任务tm_task主键
     * @return 结果
     */
    public int deleteTmTaskByTaskId(Long taskId);

    String genderLeaseCode();

    int insertSelective(TmTask bean);

    int insertAgreement(TmTask task);

    String genderBackCode();

    int insertTmTaskByBackInfo(BackApplyInfo backApplyInfo);

    int insertAgreementByBackInfo(BackApplyInfo backApplyInfo);
}
